==> haskell-pager-0.1.1.0-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-KLizKZeMjhWAs7QTqClFV
key:                  pager-0.1.1.0-KLizKZeMjhWAs7QTqClFV
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  ee56b4246d4663b75d3e31293e6f4e94
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-KLizKZeMjhWAs7QTqClFV
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-LX1OqlTDVgXB5T9goEDWxI
    conduit-extra-1.3.8-DMXEhav2zajAIstf73Tomd directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-AJ1OoWHoMXT5AEQka8SZQl
    safe-0.3.21-ByjvVtJLwt5KrRntZowDKh terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-AQ0uv6G48XSF9HSufImToE
key:                  pager-0.1.1.0-AQ0uv6G48XSF9HSufImToE
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  6d7ae5aacf7d9d84cf609ca73fd0bf80
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-AQ0uv6G48XSF9HSufImToE
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-1PwUZeKQSSaAIlloD0uxVY
    conduit-extra-1.3.8-4NFCStHKh9n4s3SuL5Ir9b directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-DmWi6y4uxzB8TJfEwrfZjc
    safe-0.3.21-JSgKJ1qQ11UGSifs2bSHTA terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
